import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Sets registered model id.
REGISTERED_MODEL_ID = ""


# Get the registered model for the given model id.
def get_registered_model(
    mlops_client: mlops.Client, 
    get_model_request: mlops.StorageGetRegisteredModelRequest
):
    return mlops_client.storage.registered_model.get_registered_model(get_model_request)


def get_registered_model_request(model_id):
    return mlops.StorageGetRegisteredModelRequest(
        model_id=model_id
    )


def main():
    # Set up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Set up the MLOps client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    get_model_response: mlops.StorageGetRegisteredModelResponse = get_registered_model(
        mlops_client,
            get_registered_model_request(
                model_id=REGISTERED_MODEL_ID
            )
        )
    print(get_model_response)


if __name__ == "__main__":
    main()